from wiser.gcloud.services.ai_platform.prediction.ai_platform_prediction_service import (
    AIPlatformPrediction,
)

__all__ = ["AIPlatformPrediction"]
